==> yeagerai-agent-0.0.37.tar.gz: yeagerai-agent-0.0.37/README.md <==
# Yeager.ai Agent
[ WARNING: super-beta ]

[![](https://dcbadge.vercel.app/api/server/VpfmXEMN66?compact=true&style=flat)](https://discord.gg/VpfmXEMN66) [![Twitter](https://img.shields.io/twitter/url/https/twitter.com/yeagerai.svg?style=social&label=Follow%20%40YeagerAI)](https://twitter.com/yeagerai) [![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://opensource.org/license/mit/) 

Yeager.ai Agent is the first Langchain Agent creator designed to help you build, prototype, and deploy AI-powered agents with ease. With an emphasis on flexibility, interactivity, and seamless integration, Yeager.ai Agent is the perfect tool for developers, researchers, and AI enthusiasts alike.

## Quick install
`pip install yeagerai`

## Key Features
- 🚀 **Create and Test Agents and Tools On-The-Fly:** With this feature, you can quickly prototype and experiment with agents and tools without the need for a lengthy setup process. Great for fast-paced development and testing!

- 👩‍💻 **Interactive CLI:** Enjoy a user-friendly, interactive command line interface that makes it easy to navigate, manage, and execute commands with real-time feedback. It's like having a conversation with your code!

- 💾 **Session Persistent Memory:** No more lost data between sessions! Our session persistent memory ensures that your work is preserved across multiple sessions, making it easy to pick up right where you left off.

- 🌐 **Fully Integrated with the Langchain Ecosystem:** Seamlessly interact with other tools and resources in the Langchain ecosystem, allowing for efficient collaboration, sharing, and integration of your projects.


## Getting Started
To call the yeagerai Agent from the terminal, just type:

```
yeagerai
```

And start building your agents on-the-fly!

### ⚠️ Warning! GPT-4 API Access Required

If you don't have access to GPT-4 API, don't worry! You can still take advantage of Yeager.ai Agent's features through our Discord bot. 🤖

[Join our Discord server](https://discord.gg/VpfmXEMN66) to get started and interact with the Yeager.ai Agent using the GPT-4-powered bot. Our friendly community is also there to assist you, answer questions, and share their experiences.

## Documentation
For detailed information on use cases, tools, agents, toolkits, and agent executors, please visit the [Yeager.ai Agent docs]().

## Contributing
We encourage contributions to help expand and improve the Yeager.ai Agent! Please read our [CONTRIBUTING]() for guidelines on how to submit your contributions.

## License
Yeager.ai Agent is released under the MIT License. Please see the [LICENSE file](https://github.com/yeagerai/yeagerai-agent/blob/main/LICENSE) for more information.

==> yeagerai-agent-0.0.39.tar.gz: yeagerai-agent-0.0.39/README.md <==
# Yeager.ai Agent
[ WARNING: super-beta ]

[![](https://dcbadge.vercel.app/api/server/VpfmXEMN66?compact=true&style=flat)](https://discord.gg/VpfmXEMN66) [![Twitter](https://img.shields.io/twitter/url/https/twitter.com/yeagerai.svg?style=social&label=Follow%20%40YeagerAI)](https://twitter.com/yeagerai) [![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://opensource.org/license/mit/) 

Yeager.ai Agent is the first Langchain Agent creator designed to help you build, prototype, and deploy AI-powered agents with ease. With an emphasis on flexibility, interactivity, and seamless integration, Yeager.ai Agent is the perfect tool for developers, researchers, and AI enthusiasts alike.

## Quick install
`pip install yeagerai-agent`

## Key Features
- 🚀 **Create and Test Agents and Tools On-The-Fly:** With this feature, you can quickly prototype and experiment with agents and tools without the need for a lengthy setup process. Great for fast-paced development and testing!

- 👩‍💻 **Interactive CLI:** Enjoy a user-friendly, interactive command line interface that makes it easy to navigate, manage, and execute commands with real-time feedback. It's like having a conversation with your code!

- 💾 **Session Persistent Memory:** No more lost data between sessions! Our session persistent memory ensures that your work is preserved across multiple sessions, making it easy to pick up right where you left off.

- 🌐 **Fully Integrated with the Langchain Ecosystem:** Seamlessly interact with other tools and resources in the Langchain ecosystem, allowing for efficient collaboration, sharing, and integration of your projects.


## Getting Started
To call the yeagerai Agent from the terminal, just type:

```
yeagerai-agent
```

And start building your agents on-the-fly!

### ⚠️ Warnings! 

#### GPT-4 API Access Required
If you don't have access to GPT-4 API, don't worry! You can still take advantage of Yeager.ai Agent's features through our Discord bot. 🤖

[Join our Discord server](https://discord.gg/VpfmXEMN66) to get started and interact with the Yeager.ai Agent using the GPT-4-powered bot. Our friendly community is also there to assist you, answer questions, and share their experiences.

#### Not tested for windows
But if you want to contribute PRs al welcome! Just contact @jmlago#0277 on [our Discord server](https://discord.gg/VpfmXEMN66)
## Documentation
For detailed information on use cases, tools, agents, toolkits, and agent executors, please visit the [Yeager.ai Agent docs](https://yeagerai.gitbook.io/docs).

## Contributing
We encourage contributions to help expand and improve the Yeager.ai Agent! Please read our [CONTRIBUTING]() for guidelines on how to submit your contributions.

## License
Yeager.ai Agent is released under the MIT License. Please see the [LICENSE file](https://github.com/yeagerai/yeagerai-agent/blob/main/LICENSE) for more information.
